import "./SearchInput.css";
import { useCallback } from "react";
import { CrossButton } from "../../button";
import { Keys, forwardRef, isNil, isNilOrEmpty, isUndefined, mergeProps, useChainedEventCallback, useControllableState, useEventCallback, useMergedRefs } from "../../shared";
import { MagnifierIcon } from "../../icons";
import { TextInput } from "../../text-input";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerSearchInput({
  value,
  defaultValue,
  onChange,
  onValueChange,
  onKeyDown,
  icon,
  wrapperProps,
  as = "input",
  forwardedRef,
  ...rest
}) {
  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const inputRef = useMergedRefs(forwardedRef);
  const updateValue = useCallback((event, newValue) => {
    if (!isNil(onValueChange)) {
      onValueChange(event, newValue);
    }

    setValue(newValue);
  }, [onValueChange, setValue]);
  const clear = useCallback(event => {
    updateValue(event, "");
  }, [updateValue]);
  const handleChange = useChainedEventCallback(onChange, event => {
    updateValue(event, event.target.value);
  });
  const handleKeyDown = useEventCallback(event => {
    if (!isNil(onKeyDown)) {
      onKeyDown(event);
    }

    if (!event.isPropagationStopped()) {
      if (event.key === Keys.esc) {
        event.preventDefault();
        clear(event);
      }
    }
  });
  const handleClear = useEventCallback(event => {
    clear(event);
    inputRef.current.focus();
  });

  const clearButtonMarkup = !isNilOrEmpty(inputValue) && /*#__PURE__*/_jsx(CrossButton, {
    onClick: handleClear,
    size: "xs",
    condensed: true,
    className: "o-ui-search-input-clear-button",
    title: "Clear value",
    "aria-label": "Clear value"
  });

  return /*#__PURE__*/_jsx(TextInput, { ...mergeProps(rest, {
      value: inputValue,
      button: clearButtonMarkup || undefined,
      onChange: handleChange,
      onKeyDown: handleKeyDown,
      icon: isUndefined(icon) ? /*#__PURE__*/_jsx(MagnifierIcon, {}) : icon,
      wrapperProps: mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
        className: "o-ui-search-input"
      }),
      type: "search",
      autoCorrect: "off",
      spellCheck: "false",
      autoComplete: "off",
      as,
      ref: inputRef
    })
  });
}
export const SearchInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerSearchInput, { ...props,
  forwardedRef: ref
}));
SearchInput.displayName = "SearchInput";